@@ -53,7 +53,7 @@ class parseModis:
       # hdf name
       self.hdfname = filename
     else:
-      raise IOError('%s not exists' % self.hdfname)
+      raise IOError('%s not exists' % filename)
 
     if os.path.exists(self.hdfname + '.xml'):
       # xml hdf name
@@ -250,6 +250,7 @@ class parseModis:
   def confResample(self, spectral, res=None, output=None, datum='WGS84',
                   resample='NEAREST_NEIGHBOR', projtype='GEO',  utm=None,
                   projpar='( 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 )',
+                  bound=None
                   ):
     """Create the parameter file to use with resample MRT software to create
     tif file
@@ -303,6 +304,11 @@ class parseModis:
         Appendix C of MODIS reprojection tool user manual
         https://lpdaac.usgs.gov/content/download/4831/22895/file/mrt41_usermanual_032811.pdf
 
+        bound = dictionary with the following keys:
+            - max_lat
+            - max_lon
+            - min_lat
+            - min_lon
         """
     #check if spectral it's write with correct construct ( value )
     if string.find(spectral, '(') == -1 or  string.find(spectral, ')') == -1:
@@ -322,8 +328,14 @@ class parseModis:
     conFile.write("INPUT_FILENAME = %s\n" % self.hdfname)
     conFile.write("SPECTRAL_SUBSET = %s\n" % spectral)
     conFile.write("SPATIAL_SUBSET_TYPE = INPUT_LAT_LONG\n")
-    # return the boundary from the input xml file
-    bound = self.retBoundary()
+    if not bound:
+      # return the boundary from the input xml file
+      bound = self.retBoundary()
+    else:
+      if 'max_lat' not in bound or 'min_lat' not in bound  or \
+      'min_lon' not in bound or 'max_lon' not in bound:
+          raise IOError('bound variable is a dictionary with the following ' \
+                        'keys: max_lat, min_lat, min_lon, max_lon')
     # Order:  UL: N W  - LR: S E
     conFile.write("SPATIAL_SUBSET_UL_CORNER = ( %f %f )\n" % (bound['max_lat'],
                                                               bound['min_lon']))
@@ -362,6 +374,7 @@ class parseModis:
   def confResample_swath(self, sds, geoloc, res, output=None, 
                   sphere='8', resample='NN', projtype='GEO',  utm=None,
                   projpar='0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0',
+                  bound=None
                   ):
     """Create the parameter file to use with resample MRT software to create
        tif file
@@ -425,6 +438,12 @@ class parseModis:
         projpar = a list of projection parameters, for more info check
         the Appendix C of MODIS reprojection tool user manual
         https://lpdaac.usgs.gov/content/download/4831/22895/file/mrt41_usermanual_032811.pdf
+
+        bound = dictionary with the following keys:
+            - max_lat
+            - max_lon
+            - min_lat
+            - min_lon
         """
     # output name
     if not output:
@@ -442,8 +461,14 @@ class parseModis:
     conFile.write("GEOLOCATION_FILENAME = %s\n" % geoloc)
     conFile.write("INPUT_SDS_NAME = %s\n" % sds)
     conFile.write("OUTPUT_SPATIAL_SUBSET_TYPE = LAT_LONG\n")
-    # return the boundary from the input xml file
-    bound = self.retBoundary()
+    if not bound:
+      # return the boundary from the input xml file
+      bound = self.retBoundary()
+    else:
+      if 'max_lat' not in bound or 'min_lat' not in bound  or \
+      'min_lon' not in bound or 'max_lon' not in bound:
+          raise IOError('bound variable is a dictionary with the following ' \
+                        'keys: max_lat, min_lat, min_lon, max_lon')
     # Order:  UL: N W  - LR: S E
     conFile.write("OUTPUT_SPACE_UPPER_LEFT_CORNER (LONG LAT) = %f %f\n" % (bound['max_lat'],
                                                               bound['min_lon']))
@@ -829,4 +854,4 @@ class parseModisMulti:
     output.write('<!DOCTYPE GranuleMetaDataFile SYSTEM "http://ecsinfo.gsfc.' \
     'nasa.gov/ECSInfo/ecsmetadata/dtds/DPL/ECS/ScienceGranuleMetadata.dtd">')
     output.write(self.ElementTree.tostring(granule))
-    output.close()
\ No newline at end of file
+    output.close()
